
/**
 * 订单详情流程启动
 */
define(function(require, exports) {
	require('./config');  //引入配置项
	require('./tool');    //引入工具集
	
	C.Mode = require('./mode');
	C.Mode.initialize();
	
	/**
	 * 订单详情单元数据模型
	 * @class DetailModel
	 * @name DetailModel
 	 */
	var DetailModel = Backbone.Model.extend({
		initialize: function() {
			this.bind('change', this.render, this);
 		},
		/**
		 * change
 		 */
 		render: function() {
			C.OrderDetail.render();
 		}
	});
	
	/**
	 * 订单详情视图
	 * @class DetailView
	 * @name DetailView
	 */
	var DetailView = Backbone.View.extend({
		el: "#order-detail",
		model: new DetailModel(),
		events: {
			'click button': 'toggleCollapse',
			'click .pursue-item': 'toggleItem'
		},
		_template: {
			'n0': $('#order-detail-template-n-dg').html(),
			'n1': $('#order-detail-template-n-hm').html(),
			'n2': $('#order-detail-template-n-hm').html(),
			'n3': $('#order-detail-template-n-zh').html(),
			'n5': $('#order-detail-template-n-zs').html(),
			's0': $('#order-detail-template-s-dg').html(),
			's1': $('#order-detail-template-s-hm').html(),
			's2': $('#order-detail-template-s-hm').html(),
		},
		initialize: function() {
			//Hook
			this.content = $('#order-detail-con');
		},
		render: function() {
			//根据model类型选择模板
			var _model = this.model.toJSON();
			try {
				this.content.html(_.template(this._template[C.Lottery.getDetailTag(_model)], _model));
			} catch (e) {    //模板解析错误
				this.exception('网络异常, 请稍候再试!');
			}
			
			
			//加载完成回调，之后修改为事件驱动
			C.Mode.detailLoadCallback(_model);

			//标红
			C.Lottery.addLuckyEffect($('.effect'), _model);
			
			return this;
		},
		/**
		 * 清空
		 * @name clear
		 * @param {node/string} frag 
		 */
		clear: function() {
			this.content.empty();
		},
		/**
		 * 拉取数据
		 * @name getData
		 * @param {string} detail  订单ID（验证） 
		 */
		getData: function() {
			//清空
			this.model.clear({silent: true}); 
			this.clear();
			
			var	lotteryType, orderType, url;
	
			lotteryType = this.lotteryType = _lotteryType;
			orderType = this.orderType = _orderType;
			this.process = _process;        //赠送进度，详情中无该数据
			this.dbType = _dbType;
			url = C.Config.getDomain() + C.Config.getDetailInterface(orderType) + '?callback=C.OrderDetail.handleData&sid=' + _sid + '&outerId=' + _outerId + '&typeId=' + lotteryType + '&issueId=' + _issueId + '&dbType=' + _dbType;
			
			var self = this;
			//设置过期时间
			this._timer = setTimeout(function() {
				self.exception('网络异常, 请稍候再试!');
				self.getDataException = true;
			}, 20000);
			C.Tool.getScript(url);
		},
		/**
		 * 处理数据
		 * @name setData
		 * @param {node/string} frag 
		 */
		handleData: function(data) {
			clearTimeout(this._timer);  //清除定时器
			if (this.getDataException) { //若异常已发生，则不在对数据进行处理
				return;
			}
			if (data.status) {	
				data.lotteryType = this.lotteryType;
				data.orderType = this.orderType;
				data.process = this.process;
				data.dbType = this.dbType;
				this.model.set(data);
			} else {
				//登录失效
				if (data.resultCode === 'ERR_LOGIN') {
					C.Mode.errorLoginException(this);
				} else if (data.resultCode === 'ERR_PLAY_DATA') {
					this.exception('暂不支持该订单详情');
				} else {
					this.exception('网络异常, 请稍候再试!');
				}
			}
		},
		/**
		 * 异常处理
		 * @name exception
		 * @param {string} str  异常内容
		 */
		exception: function(str) {
			var div = this.content.find('.exp');
			if (!div.length) {
				div = $('<div class="exp"></div>');
				this.content.append(div);
			}
			C.Mode.detailLoadFailCallback();
			div.html(str);
		},
		toggleCollapse: function(e) {
			var triggerNode = $(e.target),
				infoNode = triggerNode.closest('dd').next();
			if (triggerNode.hasClass('fold')) {
				triggerNode.attr('class', 'unfold');
				infoNode.removeClass('no-visible');
			} else {
				triggerNode.attr('class', 'fold');
				infoNode.addClass('no-visible');
			}
		},
		continueBuy: function() {
			C.Mode.continueBuy(this.model.toJSON());
		},
		toggleItem: function(e) {
			var triggerNode = $(e.currentTarget),
				tagNode = triggerNode.find('.issue'),
				infoNode = triggerNode.next();
			if (tagNode.hasClass('unfold')) {
				tagNode.attr('class', 'issue fold');
				infoNode.addClass('no-visible');
			} else {
				$('.pursue-item').each(function(index, item) {
					var _tagNode = $(item).find('.issue');
					if (_tagNode.hasClass('unfold')) {
						_tagNode.attr('class', 'issue fold');
						$(item).next().addClass('no-visible');
					}
				});	
				
				tagNode.attr('class', 'issue unfold');
				infoNode.removeClass('no-visible');

				if (triggerNode.attr('data-item') === 'false') {
					var model = this.model.toJSON(), 
						url = C.Config.getDomain() + C.Config.getDetailInterface(model.orderType) + '?callback=C.OrderDetail.handlePursue&sid=' + _sid + '&outerId=' + model.idHelper + '&typeId=' + model.lotteryType + '&issueId=' + triggerNode.attr('data-issue') + '&dbType=' + model.dbType;
					
					this.activePursueItem = {
						node: infoNode,
						trigger: triggerNode
					};
					C.Tool.getScript(url);
				}
			}	
		},
		handlePursue: function(data) {
			var item = this.activePursueItem;
			this.activePursueItem = null;

			item.node.find('.loading').remove();
			item.trigger.attr('data-item', 'true');

			var arr = [],  sHtml = '',
				textNode = item.node.find('.info');
			_.each(data.orderNumber, function(order) {
				_.each(order.formatedLotteryNumbers, function(num) {
					arr.push(num + ' ' + order.multi + '倍');
				});							
			});

			sHtml = '投注号码: <div class="effect">' + arr.join('<br/>') + '</div>' + textNode.html();
			textNode.html(sHtml).removeClass('hidden');
			
			//标红
			C.Lottery.addLuckyEffect(textNode.find('.effect'), this.model.toJSON());
		}
	});

	C.OrderDetail = new DetailView();
	C.OrderDetail.$el.removeClass('hidden');
	C.OrderDetail.getData();	
});